package coil.geek.storage;

import java.io.IOException;
import java.util.Random;

import coil.geek.storage.PersistentCacheLoader.CacheType;

public class CacheLoaderBenchmark {
	
	static {
		System.setProperty("coil.geek.storage.max-size", "1000000");
	}
	
	public static void main(String ...args) throws IOException {
		for (CacheType p : PersistentCacheLoader.CacheType.values()) {
			long start = System.currentTimeMillis();
			benchmark(p,1000);
			long end = System.currentTimeMillis();
			System.out.println("Test 10K reads and writes on " + p.name() + " at " + ((end-start)/1000F) + " sec.");
		}
	}

	private static void benchmark(CacheType p, int size) throws IOException {
		Random r = new Random();
		IntVector data = new IntVector(1,2,3,4,5);
		VectorProvider<IntVector> backend = new VectorProvider<IntVector>();
		PersistentCacheLoader<IntVector> storage = PersistentCacheLoader.init(p, backend);
		for (int i = 0; i < 10; i++) {
			for (int j = 0; j < size; j++) {
				storage.save("1,2,3,4,5," + r.nextInt() % 10000, data);
			}
			for (int j = 0; j < size; j++) {
				storage.rescue("1,2,3,4,5," + r.nextInt() % 10000);
			}
		}
	}
}
