package coil.geek.storage;

import java.io.File;
import java.io.IOException;

import junit.framework.TestCase;

public class DiskCacheLoaderTest extends TestCase {

	static {
		System.setProperty("coil.geek.storage.max-size", "10000");
	}
	
	IntVector control = new IntVector(1,2,3,4,5);
	
	public void testRescue() throws IOException {
		VectorProvider<IntVector> backend = new VectorProvider<IntVector>();
		PersistentCacheLoader<IntVector> storage = PersistentCacheLoader.init(PersistentCacheLoader.CacheType.DISK, backend);
		IntVector a = storage.rescue("1,2,3,4,5");
		assertEquals(control.sum(), a.sum());
		storage.save("1,2,3,4,5", a);
		IntVector b = storage.rescue("1,2,3,4,5");
		assertEquals(control.sum(), b.sum());
	}

	public void testSave() throws IOException {
		VectorProvider<IntVector> backend = new VectorProvider<IntVector>();
		PersistentCacheLoader<IntVector> storage = PersistentCacheLoader.init(PersistentCacheLoader.CacheType.DISK, backend);
		IntVector a = storage.rescue("1,2,3,4,5");
		assertEquals(control.sum(), a.sum());
	}
	
	public void testPurge() throws IOException {
		VectorProvider<IntVector> backend = new VectorProvider<IntVector>();
		PersistentCacheLoader<IntVector> storage = PersistentCacheLoader.init(PersistentCacheLoader.CacheType.DISK, backend);
		remove(new File(System.getProperty("coil.geek.storage.base-path", "/var/tmp/geek")));
		storage.store("1,2,3,4,5", control);
		for (int i = 0; i < 100; i++)
				storage.store("1,2,3,4,5," + i, control);
		storage.purge();
		assertFalse(storage.has("1,2,3,4,5"));
	}

	private void remove(File ... files) {
		for (File f : files) {
			if (".".equals(f.getName()) || "..".equals(f.getName()))
				continue;
			if (f.isDirectory()) {
				remove(f.listFiles());
				f.delete();
			} else
				f.delete();
		}
	}

}
