package coil.geek.storage;

import java.io.IOException;
import java.io.InputStream;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import junit.framework.TestCase;

public class MysqlCacheLoaderTest extends TestCase {

	static {
		System.setProperty("coil.geek.storage.max-size", "10000");
	}

	IntVector control = new IntVector(1,2,3,4,5);

	public void testPurge() throws IOException {
		VectorProvider<IntVector> backend = new VectorProvider<IntVector>();
		PersistentCacheLoader<IntVector> storage = PersistentCacheLoader.init(PersistentCacheLoader.CacheType.MYSQL, backend);
		IntVector a = storage.rescue("1,2,3,4,5");
		assertEquals(control.sum(), a.sum());
		storage.save("1,2,3,4,5", a);
		IntVector b = storage.rescue("1,2,3,4,5");
		assertEquals(control.sum(), b.sum());
	}

	public void testRescue() throws IOException {
		VectorProvider<IntVector> backend = new VectorProvider<IntVector>();
		PersistentCacheLoader<IntVector> storage = PersistentCacheLoader.init(PersistentCacheLoader.CacheType.MYSQL, backend);
		IntVector a = storage.rescue("1,2,3,4,5");
		assertEquals(control.sum(), a.sum());
	}

	public void testSave() throws IOException {
		VectorProvider<IntVector> backend = new VectorProvider<IntVector>();
		PersistentCacheLoader<IntVector> storage = PersistentCacheLoader.init(PersistentCacheLoader.CacheType.MYSQL, backend);
		cleanDB();
		storage.store("1,2,3,4,5", control);
		for (int i = 0; i < 100; i++)
				storage.store("1,2,3,4,5," + i, control);
		storage.purge();
		assertFalse(storage.has("1,2,3,4,5"));
	}

	private void cleanDB() throws IOException {
		try {
			initConnection();
			executeQuery("TRUNCATE object_table");
		} catch (SQLException e) {
			throw new IOException(e);
		}
	}

	private ResultSet executeQuery(String sql, Object ... data) throws SQLException {
		PreparedStatement st = m_database.prepareStatement(sql);
		for (int i = 1; i <= data.length; i++) {
			if (data[i-1] instanceof String)
				st.setString(i, (String) data[i-1]);
			else if (data[i-1] instanceof InputStream)
				st.setBlob(i, (InputStream) data[i-1]);
			else
				st.setObject(i, data[i-1]);
		}
		if (st.execute())
			return st.getResultSet();
		return null;
	}
	
	private static String s_dbhost = System.getProperty("coil.geek.storage.host", "localhost");
	private static String s_dbname = System.getProperty("coil.geek.storage.database", "storage");
	private static String s_dbuser = System.getProperty("coil.geek.storage.username", "root");
	private static String s_dbpass = System.getProperty("coil.geek.storage.password", null);
	private Connection m_database;

	private void initConnection() throws SQLException {
		if (m_database != null)
			m_database.close();
		m_database = DriverManager.getConnection("jdbc:mysql://" + s_dbhost + "/" + s_dbname, s_dbuser, s_dbpass);
		m_database.setAutoCommit(true);
	}
}
